pub struct DatabentoSubscriptionAck {
pub schema: String,
pub message: String,
pub ts_received: u64,
}Expand description
Subscription acknowledgement from the Databento gateway.
Fields
schema: Stringmessage: Stringts_received: u64Trait Implementations
Sourceimpl Clone for DatabentoSubscriptionAck
impl Clone for DatabentoSubscriptionAck
Sourcefn clone(&self) -> DatabentoSubscriptionAck
fn clone(&self) -> DatabentoSubscriptionAck
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatabentoSubscriptionAck
impl Debug for DatabentoSubscriptionAck
Sourceimpl From<SubscriptionAckEvent> for DatabentoSubscriptionAck
impl From<SubscriptionAckEvent> for DatabentoSubscriptionAck
Sourcefn from(event: SubscriptionAckEvent) -> Self
fn from(event: SubscriptionAckEvent) -> Self
Converts to this type from the input type.
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for DatabentoSubscriptionAckwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for DatabentoSubscriptionAckwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for DatabentoSubscriptionAck
impl<'py> IntoPyObject<'py> for DatabentoSubscriptionAck
Sourcetype Target = DatabentoSubscriptionAck
type Target = DatabentoSubscriptionAck
The Python output type
Sourcetype Output = Bound<'py, <DatabentoSubscriptionAck as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DatabentoSubscriptionAck as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DatabentoSubscriptionAck
impl PyClass for DatabentoSubscriptionAck
Sourceimpl PyClassImpl for DatabentoSubscriptionAck
impl PyClassImpl for DatabentoSubscriptionAck
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Subscription acknowledgement from the Databento gateway.
const RAW_DOC: &'static CStr = /// Subscription acknowledgement from the Databento gateway.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<DatabentoSubscriptionAck as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<DatabentoSubscriptionAck>
type Layout = <<DatabentoSubscriptionAck as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<DatabentoSubscriptionAck>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForDatabentoSubscriptionAck
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyStubType for DatabentoSubscriptionAck
impl PyStubType for DatabentoSubscriptionAck
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
fn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for DatabentoSubscriptionAck
impl PyTypeInfo for DatabentoSubscriptionAck
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for DatabentoSubscriptionAck